@@ -1,5 +1,5 @@
 # This file is part of Rubber and thus covered by the GPL
-# (c) Emmanuel Beffara, 2002--2005
+# (c) Emmanuel Beffara, 2002--2006
 """
 This is the command line interface for the information extractor.
 """
@@ -15,13 +15,21 @@ from rubber.version import *
 import rubber.cmdline
 
 class Main (rubber.cmdline.Main):
+	def __init__ (self):
+		rubber.cmdline.Main.__init__(self)
+		msg.write = self.stdout_write
+
+	def stdout_write (self, text, level=0):
+		sys.stdout.write(text + "\n")
+
 	def short_help (self):
-		msg(0, _("""\
+		sys.stderr.write(_("""\
 usage: rubber-info [options] source
-For more information, try `rubber-info --help'."""))
+For more information, try `rubber-info --help'.
+"""))
 
 	def help (self):
-		msg(0, _("""\
+		print _("""\
 This is Rubber's information extractor version %s.
 usage: rubber-info [options] source
 available options:
@@ -36,7 +44,7 @@ actions:
   --rules     print the dependency rules including intermediate results
   --version   print the program's version and exit
   --warnings  show all LaTeX warnings\
-""") % version)
+""") % version
 
 	def parse_opts (self, cmdline):
 		try:
@@ -70,7 +78,7 @@ actions:
 				sys.exit(0)
 			else:
 				if self.act:
-					msg.error(_("You must specify only one action."))
+					sys.stderr.write(_("You must specify only one action.\n"))
 					sys.exit(1)
 				self.act = opt[2:]
 		return args
@@ -88,20 +96,18 @@ actions:
 			"This is Rubber's information extractor version %s.") % version)
 
 		if len(args) != 1:
-			msg.error(_("You must specify one source file."))
+			sys.stderr.write(_("You must specify one source file.\n"))
 			sys.exit(1)
-		if exists(args[0] + ".tex"):
-			src = args[0]
-		elif exists(args[0]):
-			src, ext = splitext(args[0])
-		else:
-			msg.error(_("I cannot find %s.") % args[0])
+
+		src = args[0]
+		if self.env.set_source(src):
+			sys.stderr.write(_("I cannot find %s.\n") % src)
 			sys.exit(1)
 
 		if self.act == "deps":
 			self.prepare(src)
 			deps = {}
-			for dep in self.env.main.sources.values():
+			for dep in self.env.main.source_nodes():
 				for file in dep.leaves():
 					deps[file] = None
 			print string.join(deps.keys())
@@ -116,14 +122,14 @@ actions:
 				if seen.has_key(node):
 					continue
 				seen[node] = None
-				if len(node.sources.keys()) == 0:
+				if len(node.sources) == 0:
 					continue
-				print "\n%s:" % string.join(node.prods),
-				print string.join(node.sources.keys())
-				next.extend(node.sources.values())
+				print "\n%s:" % string.join(node.products),
+				print string.join(node.sources)
+				next.extend(node.source_nodes())
 		else:
 			self.prepare(src, parse=0)
-			return self.info_log(src, self.act)
+			return self.info_log(self.act)
 
 		return 0
 
@@ -133,14 +139,14 @@ actions:
 		"""
 		env = self.env
 
-		if env.set_source(src):
-			sys.exit(1)
 		if env.make_source():
 			sys.exit(1)
 
 		if not parse:
 			return
 
+		for dir in self.path:
+			env.main.do_path(dir)
 		for cmd in self.prologue:
 			cmd = parse_line(cmd, {})
 			env.main.command(cmd[0], cmd[1:], {'file': 'command line'})
@@ -151,13 +157,13 @@ actions:
 			cmd = parse_line(cmd, {})
 			env.main.command(cmd[0], cmd[1:], {'file': 'command line'})
 
-	def info_log (self, src, act):
+	def info_log (self, act):
 		"""
 		Check for a log file and extract information from it if it exists,
 		accroding to the argument's value.
 		"""
 		log = self.env.main.log
-		ret = log.read(src + ".log")
+		ret = log.read(self.env.main.target + ".log")
 		if ret == 1:
 			msg.error(_("The log file is invalid."))
 			return 1
@@ -166,27 +172,29 @@ actions:
 			return 1
 
 		if act == "boxes":
-			if not log.show_boxes():
+			if not msg.display_all(log.get_boxes()):
 				msg.info(_("There is no bad box."))
 		elif act == "check":
-			if log.show_errors(): return 0
+			if msg.display_all(log.get_errors()): return 0
 			msg.info(_("There was no error."))
-			if log.show_references(): return 0
+			if msg.display_all(log.get_references()): return 0
 			msg.info(_("There is no undefined reference."))
-			if not log.show_warnings():	msg.info(_("There is no warning."))
-			if not log.show_boxes(): msg.info(_("There is no bad box."))
+			if not msg.display_all(log.get_warnings()):
+				msg.info(_("There is no warning."))
+			if not msg.display_all(log.get_boxes()):
+				msg.info(_("There is no bad box."))
 		elif act == "errors":
-			if not log.show_errors():
+			if not msg.display_all(log.get_errors()):
 				msg.info(_("There was no error."))
 		elif act == "refs":
-			if not log.show_references():
+			if not msg.display_all(log.get_references()):
 				msg.info(_("There is no undefined reference."))
 		elif act == "warnings":
-			if not log.show_warnings():
+			if not msg.display_all(log.get_warnings()):
 				msg.info(_("There is no warning."))
 		else:
-			msg.error(_("\
-I don't know the action `%s'. This should not happen.") % act)
+			sys.stderr.write(_("\
+I don't know the action `%s'. This should not happen.\n") % act)
 			return 1
 		return 0
 
@@ -197,5 +205,5 @@ I don't know the action `%s'. This should not happen.") % act)
 		try:
 			self.main(cmdline)
 		except KeyboardInterrupt:
-			msg.error(_("*** interrupted"))
+			msg(0, _("*** interrupted"))
 			return 2
